==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/table/lang/lv.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'lv', {
	border: 'Rāmja izmērs',
	caption: 'Leģenda',
	cell: {
		menu: 'Šūna',
		insertBefore: 'Pievienot šūnu pirms',
		insertAfter: 'Pievienot šūnu pēc',
		deleteCell: 'Dzēst rūtiņas',
		merge: 'Apvienot rūtiņas',
		mergeRight: 'Apvieno pa labi',
		mergeDown: 'Apvienot uz leju',
		splitHorizontal: 'Sadalīt šūnu horizontāli',
		splitVertical: 'Sadalīt šūnu vertikāli',
		title: 'Šūnas uzstādījumi',
		cellType: 'Šūnas tips',
		rowSpan: 'Apvienotas rindas',
		colSpan: 'Apvienotas kolonas',
		wordWrap: 'Vārdu pārnese',
		hAlign: 'Horizontālais novietojums',
		vAlign: 'Vertikālais novietojums',
		alignBaseline: 'Pamatrinda',
		bgColor: 'Fona krāsa',
		borderColor: 'Rāmja krāsa',
		data: 'Dati',
		header: 'Virsraksts',
		yes: 'Jā',
		no: 'Nē',
		invalidWidth: 'Šūnas platumam jābūt skaitlim',
		invalidHeight: 'Šūnas augstumam jābūt skaitlim',
		invalidRowSpan: 'Apvienojamo rindu skaitam jābūt veselam skaitlim',
		invalidColSpan: 'Apvienojamo kolonu skaitam jābūt veselam skaitlim',
		chooseColor: 'Izvēlēties'
	},
	cellPad: 'Rūtiņu nobīde',
	cellSpace: 'Rūtiņu atstatums',
	column: {
		menu: 'Kolonna',
		insertBefore: 'Ievietot kolonu pirms',
		insertAfter: 'Ievieto kolonu pēc',
		deleteColumn: 'Dzēst kolonnas'
	},
	columns: 'Kolonnas',
	deleteTable: 'Dzēst tabulu',
	headers: 'Virsraksti',
	headersBoth: 'Abi',
	headersColumn: 'Pirmā kolona',
	headersNone: 'Nekas',
	headersRow: 'Pirmā rinda',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Rāmju izmēram jābūt skaitlim',
	invalidCellPadding: 'Šūnu atkāpēm jābūt pozitīvam skaitlim',
	invalidCellSpacing: 'Šūnu atstarpēm jābūt pozitīvam skaitlim',
	invalidCols: 'Kolonu skaitam jābūt lielākam par 0',
	invalidHeight: 'Tabulas augstumam jābūt skaitlim',
	invalidRows: 'Rindu skaitam jābūt lielākam par 0',
	invalidWidth: 'Tabulas platumam jābūt skaitlim',
	menu: 'Tabulas īpašības',
	row: {
		menu: 'Rinda',
		insertBefore: 'Ievietot rindu pirms',
		insertAfter: 'Ievietot rindu pēc',
		deleteRow: 'Dzēst rindas'
	},
	rows: 'Rindas',
	summary: 'Anotācija',
	title: 'Tabulas īpašības',
	toolbar: 'Tabula',
	widthPc: 'procentuāli',
	widthPx: 'pikseļos',
	widthUnit: 'platuma mērvienība'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/lv.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'lv', {
	border: 'Rāmja izmērs',
	caption: 'Leģenda',
	cell: {
		menu: 'Šūna',
		insertBefore: 'Pievienot šūnu pirms',
		insertAfter: 'Pievienot šūnu pēc',
		deleteCell: 'Dzēst rūtiņas',
		merge: 'Apvienot rūtiņas',
		mergeRight: 'Apvieno pa labi',
		mergeDown: 'Apvienot uz leju',
		splitHorizontal: 'Sadalīt šūnu horizontāli',
		splitVertical: 'Sadalīt šūnu vertikāli',
		title: 'Šūnas uzstādījumi',
		cellType: 'Šūnas tips',
		rowSpan: 'Apvienotas rindas',
		colSpan: 'Apvienotas kolonas',
		wordWrap: 'Vārdu pārnese',
		hAlign: 'Horizontālais novietojums',
		vAlign: 'Vertikālais novietojums',
		alignBaseline: 'Pamatrinda',
		bgColor: 'Fona krāsa',
		borderColor: 'Rāmja krāsa',
		data: 'Dati',
		header: 'Virsraksts',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Jā',
		no: 'Nē',
		invalidWidth: 'Šūnas platumam jābūt skaitlim',
		invalidHeight: 'Šūnas augstumam jābūt skaitlim',
		invalidRowSpan: 'Apvienojamo rindu skaitam jābūt veselam skaitlim',
		invalidColSpan: 'Apvienojamo kolonu skaitam jābūt veselam skaitlim',
		chooseColor: 'Izvēlēties'
	},
	cellPad: 'Rūtiņu nobīde',
	cellSpace: 'Rūtiņu atstatums',
	column: {
		menu: 'Kolonna',
		insertBefore: 'Ievietot kolonu pirms',
		insertAfter: 'Ievieto kolonu pēc',
		deleteColumn: 'Dzēst kolonnas'
	},
	columns: 'Kolonnas',
	deleteTable: 'Dzēst tabulu',
	headers: 'Virsraksti',
	headersBoth: 'Abi',
	headersColumn: 'Pirmā kolona',
	headersNone: 'Nekas',
	headersRow: 'Pirmā rinda',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Rāmju izmēram jābūt skaitlim',
	invalidCellPadding: 'Šūnu atkāpēm jābūt pozitīvam skaitlim',
	invalidCellSpacing: 'Šūnu atstarpēm jābūt pozitīvam skaitlim',
	invalidCols: 'Kolonu skaitam jābūt lielākam par 0',
	invalidHeight: 'Tabulas augstumam jābūt skaitlim',
	invalidRows: 'Rindu skaitam jābūt lielākam par 0',
	invalidWidth: 'Tabulas platumam jābūt skaitlim',
	menu: 'Tabulas īpašības',
	row: {
		menu: 'Rinda',
		insertBefore: 'Ievietot rindu pirms',
		insertAfter: 'Ievietot rindu pēc',
		deleteRow: 'Dzēst rindas'
	},
	rows: 'Rindas',
	summary: 'Anotācija',
	title: 'Tabulas īpašības',
	toolbar: 'Tabula',
	widthPc: 'procentuāli',
	widthPx: 'pikseļos',
	widthUnit: 'platuma mērvienība'
} );
